summaryrefslogtreecommitdiffstats
path: root/src/journal/journald-socket.c
diff options
context:
space:
mode:
authorZbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>2024-02-19 11:54:06 +0100
committerZbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>2024-02-19 11:56:28 +0100
commit68a7ab7d8d1ee6bc611c5b1224a68d409e06343f (patch)
treeaee35f666bb7891765db8c2e2d9941f138cdbb8b /src/journal/journald-socket.c
parentvmspawn: rework --help (diff)
downloadsystemd-68a7ab7d8d1ee6bc611c5b1224a68d409e06343f.tar.xz
systemd-68a7ab7d8d1ee6bc611c5b1224a68d409e06343f.zip
journal: use the usual spelling of "serialize"
Diffstat (limited to '')
-rw-r--r--src/journal/journald-socket.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/journal/journald-socket.c b/src/journal/journald-socket.c
index 1fb204ea83..24c8f05d45 100644
--- a/src/journal/journald-socket.c
+++ b/src/journal/journald-socket.c
@@ -47,7 +47,7 @@ static int server_open_forward_socket(Server *s) {
return 1;
}
-static inline bool must_serialise(struct iovec iov) {
+static inline bool must_serialize(struct iovec iov) {
/* checks an iovec of the form FIELD=VALUE to see if VALUE needs binary safe serialisation:
* See https://systemd.io/JOURNAL_EXPORT_FORMATS/#journal-export-format for more information
* on binary safe serialisation for the journal export format */
@@ -89,7 +89,7 @@ int server_forward_socket(
if (r <= 0)
return r;
/* We need a newline after each iovec + 4 for each we have to serialise in a binary safe way
* + 1 for the final __REALTIME_TIMESTAMP metadata field. */
size_t n = n_iovec * 5 + 1;
@@ -113,7 +113,7 @@ int server_forward_socket(
struct iovec nl = IOVEC_MAKE_STRING("\n");
size_t iov_idx = 0, len_idx = 0;
FOREACH_ARRAY(i, iovec, n_iovec) {
- if (must_serialise(*i)) {
+ if (must_serialize(*i)) {
const uint8_t *c;
c = memchr(i->iov_base, '=', i->iov_len);
@@ -89,7 +89,7 @@ int server_forward_socket(
if (r <= 0)
return r;
- /* We need a newline after each iovec + 4 for each we have to serialise in a binary safe way
+ /* We need a newline after each iovec + 4 for each we have to serialize in a binary safe way
* + 1 for the final __REALTIME_TIMESTAMP metadata field. */
size_t n = n_iovec * 5 + 1;